#
# spec file for package fsarchiver
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fsarchiver
Version:        0.8.7
Release:        1.3
Summary:        Filesystem Archiver
License:        GPL-2.0-only
Group:          Productivity/Archiving/Backup
URL:            http://www.fsarchiver.org
Source0:        https://github.com/fdupoux/fsarchiver/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        HOWTO
# PATCH-FIX-UPSTREAM Remove conflicting uses of reserved identifiers
Patch0:         fsarchiver-types.patch
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(ext2fs)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)

%description
FSArchiver is a system tool that allows you to save the contents of
a file-system to a compressed archive file. The file-system can be
restored on a partition which has a different size and it can be
restored on a different file-system. Unlike tar/dar, FSArchiver also
creates the file-system when it extracts the data to partitions.
Everything is checksummed in the archive in order to protect the data.
If the archive is corrupt, you just loose the current file, not
the whole archive.

%prep
%setup -q
%patch0 -p1
cp -p %{SOURCE1} .

%build
%configure
make %{?_smp_mflags} V=1

%install
%make_install

%files
%license COPYING
%doc ChangeLog HOWTO NEWS README THANKS internals/
%{_sbindir}/%{name}
%{_mandir}/man?/*

%changelog
* Mon Mar 20 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.8.7:
  * Implement support for option "uuid=" for vfat
  * Update list of btrfs supported features
  * Add support for the "nrext64" feature on XFS
  * Do not error out on deleted files when option -A is used
  * Handle termination by signal in exec_command()
  * Add support for the "orphan_file" feature in EXT4
  * Do not try to save xattrs if not supported by the filesystem
* Mon Mar  1 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.8.6:
  * Add support for EXT4 fast_commit feature
  * Add support for XFS features inobtcount and bigtime
  * Fix handling of compression options on the command line
  * Specify device as the last argument in mkfs calls
* Mon Jul 16 2018 mpluskal@suse.com
- Use pkgconfig style dependencies
- Drop not needed dependencies
* Mon Jul 16 2018 mvetter@suse.com
- Update to 0.8.5:
  * Improved support for extfs filesystems (Contribution from Marcos Mello)
  * Fixed build issue with e2fsprogs < 1.41 (Contribution from Marcos Mello)
  * Fixed build issue related to xattr.h (Contribution from Lars Wendler)
- Remove fsarchiver-attr.patch: upstreamed
* Tue Feb 20 2018 mvetter@suse.com
- Update to 0.8.4:
  * Added support for zstd compression algorithm (New option “-Z”).
- Add BuildRequires: libzstd-devel.
* Fri Jan  5 2018 lazy.kent@opensuse.org
- Update to 0.8.3.
  * Implemented LZ4 compression.
- Add BuildRequires: pkgconfig(liblz4).
* Fri Sep  1 2017 lazy.kent@opensuse.org
- Update to 0.8.2.
  * Add support for the latest ext4 filesystem features.
  * Improved support of large block device when restoring extfs
    filesystems.
* Wed Jan 11 2017 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Improved support for XFS filesystem.
  * Updated documentation and comments in the sources.
* Thu Aug 11 2016 lazy.kent@opensuse.org
- Update to 0.8.0.
  * Implemented FAT filesystem support for EFI system partitions.
  * Allow user to specify new filesystem label or UUID during
    restfs.
  * Fixed more errors and warnings reported by cppcheck.
- Changes in 0.6.24.
  * Updated man page and description of the commands and options.
  * Support for sparse inode chunks on XFS v5.
  * Avoid internationalization when running commands so mkfs output
    can be parsed properly.
* Tue Jul  5 2016 lazy.kent@opensuse.org
- Update to 0.6.23.
  * Added micro-seconds to timestamp used in the name of the
    temporary directory.
  * Fixed memory leaks on failure scenarios and protect against
    buffer overflows in scanf.
  * Fixed possible failure to restore ext4 filesystems when mkfs
    running in interactive mode.
  * Fixed compilation errors with the musl libc.
- Refresh fsarchiver-attr.patch.
* Sat Feb 13 2016 lazy.kent@opensuse.org
- Update to 0.6.22.
  * Test support for extended attributes and ACLs instead of
    checking mount options.
* Fri Jan  8 2016 lazy.kent@opensuse.org
- Update to 0.6.21.
  * Removed duplicate types definitions in order to fix compilation
    errors.
  * Attempt to unmount a device four times before failing.
- Changes in 0.6.20.
  * Detect version of XFS filesystems in order to preserve it when
    they are restored.
  * Add support for XFS filesystems features introduced in XFS
    version 5.
  * Make sure the UUIDs of XFS filesystems are always preserved.
- Update fsarchiver-types.patch: partially fixed upstream.
- Correct source URL.
- Install more docs.
* Sun Oct 12 2014 crrodriguez@opensuse.org
- Add fsarchiver-attr.patch: remove dependency on libattr..it was
  never linked anyway, things still worked because glibc provides
  the same interface.
* Sat Mar  1 2014 lazy.kent@opensuse.org
- Update to 0.6.19.
  * Reverted "number of inode blocks per group" patch which caused
    a regression in release 0.6.18.
* Fri Feb 14 2014 lazy.kent@opensuse.org
- Update to 0.6.18.
  * Prepared release sources using autoconf-2.69 to add support for
    new architectures.
  * Applied patch from Berix to preserve the number of inode blocks
    per group on ext filesystems.
  * Added support for recent btrfs features (up to linux-3.14).
  * Run mkfs.btrfs with option "-f" so that it does not fail on
    devices with pre-existing filesystems.
- Remove check for unsupported openSUSE versions.
* Sat Oct 26 2013 andreas.stieger@gmx.de
- fix SLE build
* Tue Aug 20 2013 schwab@suse.de
- fsarchiver-types.patch: Remove conflicting uses of reserved identifiers
* Thu Feb 28 2013 lazy.kent@opensuse.org
- Update to 0.6.17.
  + Implemented "mkfsopt" restfs option to pass extra options to
    mkfs.
  + Fixed parsing of "/proc/self/mountinfo" (mount options were not
    parsed on new systems).
* Thu Feb  7 2013 lazy.kent@opensuse.org
- Update to 0.6.16.
  + Fixed parsing of "/proc/self/mountinfo" for systemd based
    systems.
* Sun Jun  3 2012 lazy.kent@opensuse.org
- Update to 0.6.15.
  + Added support for recent ext4 features (up to linux-3.4 /
    e2fsprogs-1.42).
- Changes in 0.6.14.
  + Added support for recent btrfs features (up to linux-3.4).
  + Fixed compilation warnings (variable ‘res’ set but not used).
* Mon Mar  5 2012 lazy.kent@opensuse.org
- Update to 0.6.13.
  + Fixed detection of the root filesystem using
    "/proc/self/mountinfo" instead of "/proc/mounts".
- Use pkgconfig(*) as build dependencies.
* Thu Nov 24 2011 lazy.kent@opensuse.org
- Corrected License tag according to SPDX Standard.
- Use full URL as a source.
- Spec clean up.
* Tue May 24 2011 lazy.kent@opensuse.org
- Made changelog more verbose -- added changes important
  for enduser
* Mon Apr 11 2011 lazy.kent@opensuse.org
- Added COPYING
- Prepare spec
* Sat Dec 25 2010 lazy.kent@opensuse.org
- Update to 0.6.12
  + Fix: get correct mount info for root device when not listed in
    /proc/mounts (eg: missing "/dev/root")
* Fri Dec  3 2010 lazy.kent.suse@gmail.com
- Update to 0.6.11
  + Updated supported btrfs compat flags to make it work with
    btrfs-2.6.35
  + The -c/--cryptpass option now supports interactive passwords:
    use "-c -"
* Sun May  9 2010 lazy.kent.suse@gmail.com
- Update to 0.6.10
  + Fixed support of symbolic links on ntfs filesystems with
    ntfs3g >= 2010.3.6
* Thu May  6 2010 lazy.kent.suse@gmail.com
- Update to 0.6.9
  + Fix in probe: show devmapper/lvm volumes even when /dev/dm-xx
    does not exist
  + Fixed restoration of very small archives (archive < 4K)
  + Fix error handling in restoration: consider ENOSPC as a fatal
    error and other fixes
  + Fix: remove all volumes of the archive instead of just
    the first one if save fails
* Sun Feb 21 2010 lazy.kent.suse@gmail.com
- Update to 0.6.8
  + Fixed critial bug: there was a risk of corruption when
    the archive was written on a smbfs/cifs filesystem
* Mon Feb  1 2010 lazy.kent.suse@gmail.com
- Update to 0.6.7
  + Added support for sparse files (sparse file on the original
    disk will be recreated as sparse file)
  + Added per-archive minimum fsarchiver version requirement
    (MAINHEADKEY_MINFSAVERSION)
  + Added dirsinfo in archives with simple files and directories
    to store stats required for progression
  + The logfile created when option -d is used now has a specific
    name so that it's not overwritten
  + The md5 checksums are now calculated using the implementation
    from libgcrypt instead of the internal one
  + The libgcrypt library is now a mandatory dependency and crypto
    cannot be disabled any more
  + Allow non root users to use "fsarchiver archinfo" as long as
    they have read permissions on the archive
- Updated HOWTO
* Mon Jan 25 2010 lazy.kent.suse@gmail.com
- Update to 0.6.6
  + Fix: don't remove the archive file when savefs/savedir fails
    because the archive already exists
  + Partitions already mounted are remounted with MS_BIND to have
    access to files hidden by mounted filesystems
  + Analyse filesystems only when they are all accessible
    to prevent having to wait and then get an error
  + Important internal changes, renaming of functions/files, and
    simplifications for better consistency
  + Fixed potential memory error in savefs/savedir with extended
    attributes (bug reported by mbiebl)
* Fri Jan  8 2010 lazy.kent.suse@gmail.com
- Update to 0.6.5
  + Retry with the default level (gzip -6) when compression of
    a data block lacks memory with bzip2/lzma
- Added Suggests
* Sun Jan  3 2010 lazy.kent.suse@gmail.com
- Update to 0.6.4
  + Improved the manpage: documented the long options, added
    examples, links, ...
  + Fixed critical bug: integer overflow for "u16 headerlen"
    when sum of attributes size > 65535
  + Introduced new fileformat: "FsArCh_002", but old format
    "FsArCh_001" is also supported
  + Using code from libblkid instead of complex implementation
    to read ntfs labels
- Added pkg-config to BuildRequires
- Removed 'export PATH' -- no need anymore
* Tue Dec 29 2009 lazy.kent.suse@gmail.com
- Update to 0.6.3
  + Dont fail when e2fsck returns 1 in extfs_mkfs() since it means
    the filesystem has been fixed
  + Display the percentage of the operation which has been
    completed when verbose >= 1 (sort of progress bar)
  + Display information about physical disks as well as partitions
    in "fsarchiver probe <mode>"
  + Fixed bug with archive splitting: the split size was sometimes
    incorrect due to an integer overflow
  + Added option "--exclude/-e <pattern>" to exclude files/dirs.
    It works for both archiving and extracting.
  + Added support for long options (--option) using getopt_long
- Removed obsolete patches
- Updated HOWTO
* Wed Dec 23 2009 lazy.kent.suse@gmail.com
- Bugfixes:
  + Fixes a integer overflow problem that affects fsarchiver when
    it's compiled in 32bit. The split size is incorrect and then
    it either splits with an incorrect volume size or it does not
    split the archives.
  + Fsarchiver fails to start on a system where libgcrypt is
    upgraded to a version which is more recent than the libgcrypt
    used at compilation time when the fsarchiver package is built.
* Wed Dec  9 2009 lazy.kent.suse@gmail.com
- Patch refresh
* Wed Dec  9 2009 lazy.kent.suse@gmail.com
- Patch to fix error when e2fsck returns exit status 1
* Wed Dec  9 2009 lazy.kent.suse@gmail.com
- Update to 0.6.2
  + Fix related the the ntfs attributes when lgetxattr returns
    a negative size
  + Saves the name of the original device where the filesystem
    is stored (FSYSHEADKEY_ORIGDEV)
  + Fixed enable options in configure: "--enable-xxx" had
    the opposite effect (Thanks to horhe)
  + Exit with an error if the user wants to use a compression level
    which is not supported (Thanks to mbiebl)
  + Fixed crash when mount fails (mntbyfsa was set to true and not
    clear if mount fails)
  + Fixed code for ntfs symlinks (they have to be recreated
    as normal files and dirs + special attributes)
  + Changed the requirement from ntfs3g-AR (advanced release)
    to ntfs3g >= 20091114 (standard release) for ntfs
  + Improvements and fixes in the autotools build chain files
    (contribution from Michael Biebl)
  + Added option "-L" to specify the label of the archive:
    it's just a comment about the contents
- Updated HOWTO
* Tue Oct  6 2009 lazy.kent.suse@gmail.com
- Update to 0.6.1
  + New encryption implementation was not thread-safe (broken when
    option -j was used)
  + Dropped openssl support (this code was disabled
    in fsarchiver-0.6.0 anyway)
- Added manpage
- Replaced openssl-devel with libgcrypt-devel in BuildRequires
* Sun Sep 13 2009 lazy.kent.suse@gmail.com
- Update to 0.5.9
  + Fixed 'fsarchiver probe' which ignored /dev/dm-0
    (first device mapper disk)
  + It now displays NTFS uuids in the archive information
    ("fsarchive archinfo archive.fsa")
  + Support for "system.ntfs_times" attribute supported
    by ntfs-3g >= 2009.4.4AR.17
  + Support for "system.ntfs_dos_name" attribute supported
    by ntfs-3g >= 2009.4.4AR.17
  + Support for "user.ntfs.efsinfo" attribute which allows to copy
    and restore encrypted files
  + Improved detection for ntfs-3g-AR and print a more explicit
    message if inappropriate version found
  + Added info about the minimum fsarchiver version required
    in the archive to allow doing checks at restfs
  + Added FSYSHEADKEY_MOUNTINFO in the fsheader to allow changing
    the ntfs-3g streams_interface in the future
- Added HOWTO
* Fri Jul 10 2009 lazy.kent.suse@gmail.com
- Update to 0.5.8
  + Preserve UUID with ntfs filesystems (64bit number written
    in boot sector at offset 0x48)
  + Fixed "fsarchiver probe": partitions having a 0 at the end
    of their number were ignored
* Mon Jun  1 2009 lazy.kent.suse@gmail.com
- Update to 0.5.7
  + Added detection of partitions with no known filesystem
    in "fsarchive probe"
* Sat May 23 2009 lazy.kent.suse@gmail.com
- Build with lzma support
* Fri May 22 2009 lazy.kent.suse@gmail.com
- Initial package created - 0.5.6
